==> linshare-core-1.9.2-src.tar.bz2: src/main/java/org/linagora/linshare/core/repository/GuestRepository.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2015 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2015. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.repository;

import java.util.List;

import org.linagora.linshare.core.domain.entities.Account;
import org.linagora.linshare.core.domain.entities.Guest;


public interface GuestRepository extends UserRepository<Guest> {
	 /** Search some guests.
	  * (start matching)
	 * @param mail user mail.
	 * @param firstName user first name.
	 * @param lastName user last name.
	 * @param ownerLogin login of the user who creates the searched guest(s).
     * @return a list of matching users.
     */
    List<Guest> searchGuest(Account owner, String mail, String firstName, String lastName);

    /** Find outdated guest accounts.
     * @return a list of outdated guests (null if no one found).
     */
    List<Guest> findOutdatedGuests();


	 /** Search some guests.
	  * anyWhere matching
     * @param mail user mail.
     * @param firstName user first name.
     * @param lastName user last name.
     * @param ownerLogin login of the user who creates the searched guest(s).
     * @return a list of matching users.
     */
    List<Guest> searchGuestAnyWhere(String mail, String firstName, String lastName);
    List<Guest> searchGuestAnyWhere(String firstName, String lastName);
    List<Guest> searchGuestAnyWhere(String pattern);

    void evict(Guest entity);
}

==> linshare-core-1.10.0-src.tar.bz2: src/main/java/org/linagora/linshare/core/repository/GuestRepository.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2015 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2015. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */
package org.linagora.linshare.core.repository;

import java.util.List;

import org.linagora.linshare.core.domain.entities.Account;
import org.linagora.linshare.core.domain.entities.Guest;


public interface GuestRepository extends UserRepository<Guest> {
	 /** Search some guests.
	  * (start matching)
	 * @param mail user mail.
	 * @param firstName user first name.
	 * @param lastName user last name.
	 * @param ownerLogin login of the user who creates the searched guest(s).
     * @return a list of matching users.
     */
    List<Guest> searchGuest(Account owner, String mail, String firstName, String lastName);

	/**
	 * Find outdated guest account identifiers.
	 * 
	 * @return a list of outdated guest identifiers
	 */
	List<String> findOutdatedGuestIdentifiers();


	 /** Search some guests.
	  * anyWhere matching
     * @param mail user mail.
     * @param firstName user first name.
     * @param lastName user last name.
     * @param ownerLogin login of the user who creates the searched guest(s).
     * @return a list of matching users.
     */
    List<Guest> searchGuestAnyWhere(String mail, String firstName, String lastName);
    List<Guest> searchGuestAnyWhere(String firstName, String lastName);
    List<Guest> searchGuestAnyWhere(String pattern);

    void evict(Guest entity);
}
